#!/usr/bin/env python
# -*- coding: utf-8 -*-

# # IREP: registre des émissions polluantes
# 
# Ce jeu de données est disponible sous le nombre [Registre des émissions polluantes](http://www.georisques.gouv.fr/dossiers/irep/telechargement).

# In[1]:


from jyquickhelper import add_notebook_menu
add_notebook_menu()


# In[2]:


get_ipython().run_line_magic('matplotlib', 'inline')


# ## Récupération des données
# 
# Les données ont été préalablement téléchargées et zippées.

# In[3]:


from ensae_teaching_cs.data import load_irep
load_irep()


# In[4]:


import pandas
df = pandas.read_csv("2017/Prod_dechets_dangereux.csv")
df.head()


# In[5]:


[_ for _ in set(df.Nom_Etablissement) if "lubrizol" in _.lower()]


# In[6]:


df[df.Nom_Etablissement.str.contains("LUBRI")].head().T


# In[7]:


ets = pandas.read_csv("2017/etablissements.csv")
ets.head()


# In[8]:


ets[ets.Nom_Etablissement.str.contains("LUBRI")]


# ## Conversion des coordonnées
# 
# Les coordonnées utilisées par l'admnistration française sont souvent différentes des longitudes et latitudes, il pourrait s'agir du système [Lambert 93](https://epsg.io/2154). Il faut convertir.

# In[9]:


from pyproj import Proj, transform
p1 = Proj(init='epsg:4326')  # longitude / latidude
p2 = Proj(init='epsg:2154')  # Lambert 93
exp = (509411.0, 2494315.0)  # Rouen dans la base de données reçues.
transform(p1, p2, 1.059011, 49.434654), exp


# Ca n'a pas l'air d'être ça. On en essaye plusieurs.

# In[10]:


import warnings
from tqdm import tqdm
warnings.simplefilter("ignore")

summary = []
for i in tqdm(range(2000, 10000)):
    try:
        p2 = Proj(init='epsg:%d' % i)
    except RuntimeError:
        # does not exist
        continue
    try:
        res = transform(p1, p2, 1.059011, 49.434654)
    except RuntimeError:
        # impossible
        continue
    d = abs(res[0] - exp[0]) + abs(res[1] - exp[1])
    summary.append((d, i, res))
summary.sort()
summary[:10]


# On tombe donc sur [espg:2192](https://epsg.io/2192-8046) ou [espg:7401](https://epsg.io/7401).

# In[11]:


p2 = Proj(init='epsg:2192')
long, lat = transform(p2, p1, ets.Coordonnees_X.values, ets.Coordonnees_Y.values)
ets['LLX'] = long
ets['LLY'] = lat


# In[12]:


ets[ets.Nom_Etablissement.str.contains("LUBRI")]


# Ca a l'air de coller.

# In[13]:


ets16 = pandas.read_csv("2016/etablissements.csv")
ets17 = pandas.read_csv("2017/etablissements.csv")
p16 = pandas.read_csv("2016/Prod_dechets_dangereux.csv")
p17 = pandas.read_csv("2017/Prod_dechets_dangereux.csv")

long, lat = transform(p2, p1, ets16.Coordonnees_X.values, ets16.Coordonnees_Y.values)
ets16['LLX'] = long
ets16['LLY'] = lat

long, lat = transform(p2, p1, ets17.Coordonnees_X.values, ets17.Coordonnees_Y.values)
ets17['LLX'] = long
ets17['LLY'] = lat


# In[14]:


ets16_2 = p16.merge(ets16, on="Identifiant")
ets16_2.shape, p16.shape


# In[15]:


ets17_2 = p17.merge(ets17, on="Identifiant")
ets17_2.shape, p17.shape


# Les fusions se sont bien passées. On vérifie que les unités sont comparables.

# In[16]:


set(p16.Unite), set(p17.Unite)


# ## Vue dynamique

# In[17]:


from ipywidgets import interact


# In[18]:


@interact(annee=[2016, 2017], column=list(sorted(p16.columns)), x=(0, 100000, 100))
def show_rows(annee=2017, column='Quantite', x=100000):
    if annee == 2017:
        return ets17_2[ets17_2[column] >= x].sort_values(column).T
    else:
        return ets16_2[ets16_2[column] >= x].sort_values(column).T


# ## Cartes
# 
# On regarde les projets sur la métropole en 2017.

# In[19]:


lim_metropole = [-5, 10, 41, 52]

ets17_2_metro = ets17_2[((ets17_2.LLX >= lim_metropole[0]) & (ets17_2.LLX <= lim_metropole[1]) &
                         (ets17_2.LLY >= lim_metropole[2]) & (ets17_2.LLY <= lim_metropole[3]))]
ets17_2_metro.shape, ets17_2.shape


# In[20]:


import cartopy.crs as ccrs
import cartopy.feature as cfeature
import matplotlib.pyplot as plt

fig = plt.figure(figsize=(7,7))
ax = fig.add_subplot(1, 1, 1, projection=ccrs.PlateCarree())
ax.set_extent(lim_metropole)
ax.add_feature(cfeature.OCEAN.with_scale('50m'))
ax.add_feature(cfeature.COASTLINE.with_scale('50m'))
ax.add_feature(cfeature.RIVERS.with_scale('50m'))
ax.add_feature(cfeature.BORDERS.with_scale('50m'), linestyle=':')
ax.scatter(ets17_2_metro.LLX, ets17_2_metro.LLY,
           s=ets17_2_metro.Quantite ** 0.5 / 5, alpha=0.5)
ax.set_title('France 2017\nproduction de produits dangereux');


# In[21]: